@@ -1,6 +1,6 @@
-#![cfg(all(target_os = "linux", not(target_env = "kernel")))]
+#![cfg(target_os = "linux")]
 #![doc = include_str!("../README.md")]
-#![doc(html_root_url = "https://docs.rs/selinux-sys/0.6.7")]
+#![doc(html_root_url = "https://docs.rs/selinux-sys/0.6.12")]
 #![warn(unsafe_op_in_unsafe_fn)]
 #![allow(
     non_upper_case_globals,
@@ -10,6 +10,9 @@
     clippy::upper_case_acronyms
 )]
 
+#[cfg(test)]
+mod tests;
+
 include!(concat!(env!("OUT_DIR"), "/selinux-sys.rs"));
 
 /// Unspecified SID.
@@ -28,6 +31,3 @@ pub unsafe fn avc_entry_ref_init(aeref: *mut avc_entry_ref) {
         };
     }
 }
-
-#[cfg(test)]
-mod tests;
