@@ -1,7 +1,4 @@
-#![cfg(all(test, target_os = "linux", not(target_env = "kernel")))]
-
 use std::os::raw::c_char;
-use std::ptr;
 
 #[test]
 fn is_selinux_enabled() {
@@ -11,7 +8,7 @@ fn is_selinux_enabled() {
 
 #[test]
 fn getcon() {
-    let mut context: *mut c_char = ptr::null_mut();
+    let mut context: *mut c_char = core::ptr::null_mut();
     let r = unsafe { super::getcon(&mut context) };
     assert_ne!(r, -1);
     assert!(!context.is_null());
